CustomFonts class

Constructors

CustomFonts()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

customBtnText double
getter/setter pair
customHeading double
getter/setter pair
customHeadingTwo double
getter/setter pair
customInputLabel double
getter/setter pair
customInputText double
getter/setter pair
customParagraph double
getter/setter pair
customParagraphLg double
getter/setter pair
customParagraphSm double
getter/setter pair
customParagraphXl double
getter/setter pair