CustomCalendar class

Constructors

CustomCalendar()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMonthCalendar(int month, int year, {StartWeekDay startWeekDay = StartWeekDay.sunday, dynamic startDate = DateTime, dynamic endDate = DateTime}) List<Calendar>
get the month calendar month is between from 1-12 (1 for January and 12 for December)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited